@@ -1,5 +1,5 @@
 package Net::Hadoop::Oozie;
-$Net::Hadoop::Oozie::VERSION = '0.101';
+$Net::Hadoop::Oozie::VERSION = '0.102';
 use 5.010;
 use strict;
 use warnings;
@@ -307,26 +307,44 @@ sub submit_job {
     return $res->{id}; 
 }
 
-sub suspended_workflows {
+sub _collect_suspended {
     my $self = shift;
-    my @param;
+    my $opt  = shift || {};
+
+    die "Options need to be a HASH" if ! is_hashref $opt;
+
+    my $is_coord = $opt->{is_coord};
+    my $key      = $is_coord ? 'coordinatorjobs' : 'workflows';
+
     $self->filter( { status => [qw( SUSPENDED )] } );
 
     my(@wanted);
+
     $self->_jobs_iterator(
-        jobtype => '',
+        jobtype => $is_coord ? 'coordinators' : '',
         {
+            ( $is_coord ? (
+            is_coordinator => 1,
+            ):()),
             callback => sub {
                 my $job = shift;
-                return if ! $job->{workflows};
-                push @wanted, @{ $job->{workflows} };
-            }
+                return if ! $job->{ $key };
+                push @wanted, @{ $job->{ $key } };
+            },
         }
     );
 
     return \@wanted;
 }
 
+sub suspended_workflows {
+    shift->_collect_suspended;
+}
+
+sub suspended_coordinators {
+    shift->_collect_suspended({ is_coord => 1 });
+}
+
 sub active_coordinators {
     my $self = shift;
     my $opt  = ref $_[0] eq 'HASH' ? shift @_ : {};
@@ -854,7 +872,7 @@ Net::Hadoop::Oozie
 
 =head1 VERSION
 
-version 0.101
+version 0.102
 
 =head1 SYNOPSIS
 
@@ -980,7 +998,7 @@ Required parameters are listed below.
 
 =item * oozie.wf.application.path
 
-Like /oozie_workflows/myworkflow, must be deployed there already.
+Like F</oozie_workflows/myworkflow>, must be deployed there already.
 
 =item * appName
 
@@ -996,14 +1014,14 @@ Optional parameters are listed below.
 
 If you want some variable interpolated in your script (like a date, an int,
 or whatever), pass it in the options you call the method with. if you pass
-foo => 'bar', inside the workflow you will be able to use it as ${foo}.
+C<< foo =E<62> 'bar', >> inside the workflow you will be able to use it as C<${foo}>.
 
 =item Configuration properties
 
 Useful parameters for oozie itself (like the queue name) need AFAICT an
 extra level of handling. they can be set dynamically, but need a tweak in
 the workflow definition itself, in the top config section; for instance, if
-we need to specify mapreduce.job.queuename to assign the tasks to a
+we need to specify C<mapreduce.job.queuename> to assign the tasks to a
 specific fair scheduler queue, we need to declare it in the global configuration
 section, like this:
 
@@ -1012,14 +1030,14 @@ section, like this:
         <value>${queueName}</value>
     </property>
 
-And we will call submit_job() adding this to the options hash:
+And we will call L</submit_job> adding this to the options hash:
 
     queueName => "root.<queue name>"
 
 =back
 
 This method returns a job ID which you can use directly to query the job
-status, with the job(<jobId>) method above, so you can launch a job from a
+status, with the L</job> method above, so you can launch a job from a
 script, and have a loop query the job status at regular intervals (be nice,
 please) to check when it's done (untested code :-).
 
@@ -1059,13 +1077,15 @@ please) to check when it's done (untested code :-).
 
 =head3 active_job_paths
 
+=head3 coordinators_with_the_same_appname_on_the_same_path
+
 =head3 failed_workflows_last_n_hours
 
 =head3 failed_workflows_last_n_hours_pretty
 
 =head3 job_exists
 
-This is a sugar interface on top of C<job> method. Normally the REST interface
+This is a sugar interface on top of the L</job> method. Normally the REST interface
 just dies with an C<HTTP 400> message on missing jobs. This method won't die
 and will return the data set if there is a proper response from the service.
 It will return false otherwise.
@@ -1087,6 +1107,15 @@ a coordinator):
         # do something
     }
 
+=head3 suspended_coordinators
+
+Returns an arrayref of suspended coordinators:
+
+    my $suspended = $oozie->suspended_coordinators;
+    foreach my $coord ( @{ $suspended } ) {
+        # do something
+    }
+
 =head3 suspended_workflows
 
 Returns an arrayref of suspended workflows:
@@ -1103,35 +1132,13 @@ Having coordinators like this is usually an user error when submitting jobs.
 
     my %offenders = $oozie->coordinators_with_the_same_appname_on_the_same_path;
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Burak Gursoy C<< burakE<64>cpan.org >>
-
-=item *
-
-David Morel C<< david.morelE<64>amakuru.net >>
-
-=item *
-
-Eric Herman C<< ericE<64>freesa.org >>
-
-=item *
-
-Rafael Garcia-Suarez C<< rgarciasuarezE<64>gmail.com >>
-
-=back
-
 =head1 AUTHOR
 
 David Morel <david.morel@amakuru.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by David Morel & Booking.com.
+This software is copyright (c) 2015 by David Morel & Booking.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
